@@ -1,5 +1,5 @@
+use crate::utils::{big_endian_uint256_deserialize, big_endian_uint256_serialize};
 use num256::Uint256;
-use utils::{big_endian_uint256_deserialize, big_endian_uint256_serialize};
 
 /// A thin wrapper type to change the way Uint256 is serialized.
 ///
